autowisp.astrometry.map_projections module — AutoWISP documentation

# autowisp.astrometry.map_projections module

Define projections from a sphere onto a plane.

autowisp.astrometry.map_projections.gnomonic_projection(sources, projected, **center)

  Project the given sky position to a tangent plane (gnomonic projection).

  Parameters:

    - sources (structured array-like) – The sky position to project (should have ‘RA’ and ‘Dec’ keys coordinates in degrees).

    - projected – A numpy array with ‘xi’ and ‘eta’ fields to fill with the projected coordinates (in degrees).

    - center (dict) – Should define the central ‘RA’ and ‘Dec’ around which to project.

  Returns:

    None

autowisp.astrometry.map_projections.inverse_gnomonic_projection(sources, projected, **center)

  Inverse projection from tangent plane (xi, eta) to sky position (RA, Dec)

  Parameters:

    - sources – An empty numpy array with “RA” and “Dec” fields to fill with the inverse projected of tangent plane coordinates. (in degrees)

    - projected – numpy array with “xi” and “eta” fields (in degrees)

    - center (dict) – Should define the central “RA” and “Dec” in degree

  Returns:

    None

autowisp.astrometry.map_projections.inverse_tan_projection(sources, projected, **center)

  Inverse projection from tangent plane (xi, eta) to sky position (RA, Dec)

  Parameters:

    - sources – An empty numpy array with “RA” and “Dec” fields to fill with the inverse projected of tangent plane coordinates. (in degrees)

    - projected – numpy array with “xi” and “eta” fields (in degrees)

    - center (dict) – Should define the central “RA” and “Dec” in degree

  Returns:

    None

autowisp.astrometry.map_projections.tan_projection(sources, projected, **center)

  Project the given sky position to a tangent plane (gnomonic projection).

  Parameters:

    - sources (structured array-like) – The sky position to project (should have ‘RA’ and ‘Dec’ keys coordinates in degrees).

    - projected – A numpy array with ‘xi’ and ‘eta’ fields to fill with the projected coordinates (in degrees).

    - center (dict) – Should define the central ‘RA’ and ‘Dec’ around which to project.

  Returns:

    None